@@ -1,6 +1,5 @@
 import os
 import re
-import sys
 import copy
 import json
 import difflib
@@ -14,16 +13,17 @@ from ..broker import MessageBroker
 from ..aient.src.aient.models import chatgpt
 from ..aient.src.aient.plugins import get_function_call_list, registry
 from ..prompt import worker_system_prompt, instruction_system_prompt
-from ..utils import extract_xml_content, get_current_screen_image_message, replace_xml_content, register_mcp_tools
+from ..utils import extract_xml_content, get_current_screen_image_message, replace_xml_content, register_mcp_tools, setup_logger
 
 class BaseAgent:
     """Base class for agents, handling common initialization and disposal."""
-    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str):
+    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str, graph_update_topic: str = None):
         self.goal = goal
         self.tools_json = tools_json
         self.work_dir = work_dir
         self.cache_file = Path(work_dir) / ".beswarm" / "work_agent_conversation_history.json"
         self.config = agent_config
+        self.logger = agent_config.get("logger", None)
         self.cache_messages = cache_messages
         if cache_messages and isinstance(cache_messages, bool) and cache_messages == True:
             self.cache_messages = json.loads(self.cache_file.read_text(encoding="utf-8"))
@@ -32,12 +32,23 @@ class BaseAgent:
         self.error_topic = listen_topic + ".error"
         self.publish_topic = publish_topic
         self.status_topic = status_topic
+        self.graph_update_topic = graph_update_topic
+        if self.graph_update_topic:
+            self.graph_update_subscription = self.broker.subscribe(self.handle_graph_update, self.graph_update_topic)
+
         self._subscription = self.broker.subscribe(self.handle_message, [self.listen_topic, self.error_topic])
 
+        self.graph_tree = None
+
     async def handle_message(self, message: Dict):
         """Process incoming messages. Must be implemented by subclasses."""
         raise NotImplementedError
 
+    def handle_graph_update(self, message: Dict):
+        """Handle graph update messages."""
+        if message.get("message") == "graph_updated":
+            self.graph_tree = message.get("graph")
+
     def dispose(self):
         """Cancels the subscription and cleans up resources."""
         if self._subscription:
@@ -46,8 +57,8 @@ class BaseAgent:
 
 class InstructionAgent(BaseAgent):
     """Generates instructions and publishes them to a message broker."""
-    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str):
-        super().__init__(goal, tools_json, agent_config, work_dir, cache_messages, broker, listen_topic, publish_topic, status_topic)
+    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str, graph_update_topic: str):
+        super().__init__(goal, tools_json, agent_config, work_dir, cache_messages, broker, listen_topic, publish_topic, status_topic, graph_update_topic)
 
         self.last_instruction = None
         self.agent = chatgpt(**self.config)
@@ -64,8 +75,8 @@ class InstructionAgent(BaseAgent):
                         changed_lines.append(line)
                 self.goal_diff = '\n'.join(changed_lines).strip()
 
-    def get_conversation_history(self, conversation_history: List[Dict]):
-        conversation_history = copy.deepcopy(conversation_history)
+    def get_conversation_history(self, raw_conversation_history: List[Dict]):
+        conversation_history = copy.deepcopy(raw_conversation_history)
 
         self.cache_file.write_text(json.dumps(conversation_history, ensure_ascii=False, indent=4), encoding="utf-8")
 
@@ -83,6 +94,17 @@ class InstructionAgent(BaseAgent):
             elif isinstance(conversation_history[0]["content"], list) and extracted_content:
                 conversation_history[0]["content"].append({"type": "text", "text": extracted_content})
 
+            for message in conversation_history:
+                if message.get("content") and isinstance(message["content"], str) \
+                and "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
+                    message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
+
+        for index, message in enumerate(raw_conversation_history):
+            if message.get("content") and isinstance(message["content"], str) \
+            and "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
+                message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
+                raw_conversation_history[index] = message
+
         return conversation_history
 
     async def handle_message(self, message: Dict):
@@ -124,10 +146,10 @@ class InstructionAgent(BaseAgent):
 
         self.broker.publish({"status": "new_message", "result": "\n🤖 指令智能体:\n" + raw_response}, self.status_topic)
 
-        self.last_instruction = raw_response
         instruction = extract_xml_content(raw_response, "instructions")
         if instruction:
             if len(message["conversation"]) == 1:
+                instruction = re.sub(r'^<task_complete>([\D\d\s]+)<\/task_complete>$', '', instruction, flags=re.MULTILINE)
                 instruction = (
                     "任务描述：\n"
                     f"<goal>{self.goal}</goal>\n\n"
@@ -145,15 +167,17 @@ class InstructionAgent(BaseAgent):
                     f"{instruction}"
                 )
             self.broker.publish({"instruction": instruction, "conversation": message["conversation"]}, self.publish_topic)
+            self.last_instruction = None
         else:
-            print("\n❌ 指令智能体生成的指令不符合要求，正在重新生成。")
+            self.logger.error("\n❌ 指令智能体生成的指令不符合要求，正在重新生成。")
             self.broker.publish(message, self.error_topic)
+            self.last_instruction = raw_response
 
 
 class WorkerAgent(BaseAgent):
     """Executes instructions and publishes results to a message broker."""
-    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str):
-        super().__init__(goal, tools_json, agent_config, work_dir, cache_messages, broker, listen_topic, publish_topic, status_topic)
+    def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str, graph_update_topic: str):
+        super().__init__(goal, tools_json, agent_config, work_dir, cache_messages, broker, listen_topic, publish_topic, status_topic, graph_update_topic)
 
         if self.cache_messages and isinstance(self.cache_messages, list) and len(self.cache_messages) > 1:
             first_user_message = replace_xml_content(self.cache_messages[1]["content"], "goal", goal)
@@ -170,13 +194,19 @@ class WorkerAgent(BaseAgent):
             }, self.publish_topic)
             return
 
+        for index, raw_message in enumerate(self.agent.conversation["default"]):
+            if raw_message.get("content") and isinstance(raw_message["content"], str) \
+            and "<knowledge_graph_tree>" in raw_message["content"] and self.graph_tree:
+                raw_message["content"] = replace_xml_content(raw_message["content"], "knowledge_graph_tree", self.graph_tree)
+                self.agent.conversation["default"][index] = raw_message
+
         instruction = message["instruction"]
         if "find_and_click_element" in json.dumps(self.tools_json):
             instruction = await get_current_screen_image_message(instruction)
         response = await self.agent.ask_async(instruction)
 
         if response.strip() == '':
-            print("\n❌ 工作智能体回复为空，请重新生成指令。")
+            self.logger.error("\n❌ 工作智能体回复为空，请重新生成指令。")
             self.broker.publish(message, self.error_topic)
         else:
             self.broker.publish({"status": "new_message", "result": "\n✅ 工作智能体:\n" + response}, self.status_topic)
@@ -184,22 +214,9 @@ class WorkerAgent(BaseAgent):
                 "conversation": self.agent.conversation["default"]
             }, self.publish_topic)
 
-class Tee:
-    def __init__(self, *files):
-        self.files = files
-
-    def write(self, obj):
-        for f in self.files:
-            f.write(obj)
-            f.flush()
-
-    def flush(self):
-        for f in self.files:
-            f.flush()
-
 class BrokerWorker:
     """The 'glue' class that orchestrates agents via a MessageBroker."""
-    def __init__(self, goal: str, tools: List[Union[str, Dict]], work_dir: str, cache_messages: Union[bool, List[Dict]] = None, broker = None, mcp_manager = None, task_manager = None):
+    def __init__(self, goal: str, tools: List[Union[str, Dict]], work_dir: str, cache_messages: Union[bool, List[Dict]] = None, broker = None, mcp_manager = None, task_manager = None, kgm = None):
         self.goal = goal
         self.tools = tools
         self.work_dir = Path(work_dir)
@@ -208,32 +225,33 @@ class BrokerWorker:
         self.broker = broker
         self.mcp_manager = mcp_manager
         self.task_manager = task_manager
+        self.kgm = kgm
         self.task_completion_event = asyncio.Event()
         self.final_result = None
         self._status_subscription = None
-        self.setup()
 
         self.channel = self.broker.request_channel()
         self.INSTRUCTION_TOPIC = self.channel + ".instructions"
         self.WORKER_RESPONSE_TOPIC = self.channel + ".worker_responses"
         self.TASK_STATUS_TOPIC =self.channel +  ".task_status"
+        self.GRAPH_UPDATE_TOPIC = self.channel + ".knowledge_graph"
+
+        self.setup()
 
     def setup(self):
         cache_dir = self.work_dir / ".beswarm"
         cache_dir.mkdir(parents=True, exist_ok=True)
         self.task_manager.set_root_path(self.work_dir)
+        self.kgm.set_root_path(self.work_dir)
+        self.kgm.set_publish_topic(self.GRAPH_UPDATE_TOPIC)
         self.cache_file = cache_dir / "work_agent_conversation_history.json"
         if not self.cache_file.exists():
             self.cache_file.write_text("[]", encoding="utf-8")
 
-        DEBUG = os.getenv("DEBUG", "false").lower() in ("true", "1", "t", "yes")
-        if DEBUG:
-            log_file = open(cache_dir / "history.log", "a", encoding="utf-8")
-            log_file.write(f"========== {datetime.now().strftime('%Y-%m-%d %H:%M:%S')} ==========\n")
-            original_stdout = sys.stdout
-            original_stderr = sys.stderr
-            sys.stdout = Tee(original_stdout, log_file)
-            sys.stderr = Tee(original_stderr, log_file)
+        # 创建一个文件处理器，将日志写入任务自己的目录
+        log_file_path = cache_dir / "agent.log"
+        self.logger = setup_logger(f"task_{self.work_dir.name}", log_file_path)
+        self.logger.info(f"Logger for task '{self.goal}' initialized. Log file: {log_file_path}")
 
     async def _configure_tools(self):
         mcp_list = [item for item in self.tools if isinstance(item, dict)]
@@ -256,12 +274,12 @@ class BrokerWorker:
             self.task_completion_event.set()
 
         if message.get("status") == "error":
-            print(message.get("result"))
+            self.logger.error(message.get("result"))
             self.final_result = message.get("result")
             self.task_completion_event.set()
 
         if message.get("status") == "new_message":
-            print(message.get("result"))
+            self.logger.info(message.get("result"))
 
     def _setup_agents(self):
         instruction_agent_config = {
@@ -272,7 +290,7 @@ class BrokerWorker:
                 workspace_path=self.work_dir, current_time=datetime.now().strftime("%Y-%m-%d %H:%M:%S")
             ),
             "print_log": os.getenv("DEBUG", "false").lower() in ("true", "1", "t", "yes"),
-            "temperature": 0.7, "use_plugins": False
+            "temperature": 0.7, "use_plugins": False, "logger": self.logger
         }
 
         worker_agent_config = {
@@ -283,19 +301,21 @@ class BrokerWorker:
                 shell=os.getenv('SHELL', 'Unknown'), current_time=datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                 tools_list=self.tools_json
             ),
-            "print_log": True, "temperature": 0.5, "function_call_max_loop": 100
+            "print_log": True, "temperature": 0.5, "function_call_max_loop": 100, "logger": self.logger
         }
 
         instruction_agent = InstructionAgent(
             goal=self.goal, tools_json=self.tools_json, agent_config=instruction_agent_config, work_dir=self.work_dir, cache_messages=self.cache_messages,
             broker=self.broker, listen_topic=self.WORKER_RESPONSE_TOPIC,
-            publish_topic=self.INSTRUCTION_TOPIC, status_topic=self.TASK_STATUS_TOPIC
+            publish_topic=self.INSTRUCTION_TOPIC, status_topic=self.TASK_STATUS_TOPIC,
+            graph_update_topic=self.GRAPH_UPDATE_TOPIC
         )
 
         worker_agent = WorkerAgent(
             goal=self.goal, tools_json=self.tools_json, agent_config=worker_agent_config, work_dir=self.work_dir, cache_messages=self.cache_messages,
             broker=self.broker, listen_topic=self.INSTRUCTION_TOPIC,
-            publish_topic=self.WORKER_RESPONSE_TOPIC, status_topic=self.TASK_STATUS_TOPIC
+            publish_topic=self.WORKER_RESPONSE_TOPIC, status_topic=self.TASK_STATUS_TOPIC,
+            graph_update_topic=self.GRAPH_UPDATE_TOPIC
         )
         return instruction_agent, worker_agent
 
@@ -334,7 +354,7 @@ class BrokerWorker:
                     yield message.get("result")
                     break
                 elif message.get("status") == "error":
-                    print(message.get("result"))
+                    self.logger.error(message.get("result"))
                     self.final_result = message.get("result")
                     self.task_completion_event.set()
         finally:
