@@ -34,12 +34,14 @@ def gemini_json_poccess(response_str):
         candidatesTokenCount = safe_get(response_json, "usageMetadata", "candidatesTokenCount", default=0)
         totalTokenCount = safe_get(response_json, "usageMetadata", "totalTokenCount", default=0)
 
-    content = safe_get(json_data, "parts", 0, "text", default="")
+    content = reasoning_content = safe_get(json_data, "parts", 0, "text", default="")
     b64_json = safe_get(json_data, "parts", 0, "inlineData", "data", default="")
     if b64_json:
         image_base64 = b64_json
 
     is_thinking = safe_get(json_data, "parts", 0, "thought", default=False)
+    if is_thinking:
+        content = safe_get(json_data, "parts", 1, "text", default="")
 
     function_call_name = safe_get(json_data, "functionCall", "name", default=None)
     function_full_response = safe_get(json_data, "functionCall", "args", default="")
@@ -47,7 +49,7 @@ def gemini_json_poccess(response_str):
 
     blockReason = safe_get(json_data, 0, "promptFeedback", "blockReason", default=None)
 
-    return is_thinking, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount
+    return is_thinking, reasoning_content, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount
 
 async def fetch_gemini_response_stream(client, url, headers, payload, model):
     timestamp = int(datetime.timestamp(datetime.now()))
@@ -63,11 +65,18 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model):
         parts_json = ""
         async for chunk in response.aiter_text():
             buffer += chunk
+            if buffer and "\n" not in buffer:
+                buffer += "\n"
 
             while "\n" in buffer:
                 line, buffer = buffer.split("\n", 1)
                 if line.startswith("data: "):
                     parts_json = line.lstrip("data: ").strip()
+                    try:
+                        json.loads(parts_json)
+                    except json.JSONDecodeError:
+                        logger.error(f"JSON decode error: {parts_json}")
+                        continue
                 else:
                     parts_json += line
                     parts_json = parts_json.lstrip("[,")
@@ -77,12 +86,12 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model):
                         continue
 
                 # https://ai.google.dev/api/generate-content?hl=zh-cn#FinishReason
-                is_thinking, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount = gemini_json_poccess(parts_json)
+                is_thinking, reasoning_content, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount = gemini_json_poccess(parts_json)
 
                 if is_thinking:
-                    sse_string = await generate_sse_response(timestamp, model, reasoning_content=content)
+                    sse_string = await generate_sse_response(timestamp, model, reasoning_content=reasoning_content)
                     yield sse_string
-                elif not image_base64 and content:
+                if not image_base64 and content:
                     sse_string = await generate_sse_response(timestamp, model, content=content)
                     yield sse_string
 
