@@ -3,11 +3,22 @@ from .search_web import search_web
 from .completion import task_complete
 from .search_arxiv import search_arxiv
 from .repomap import get_code_repo_map
+from .write_csv import append_row_to_csv
+from .graph import (
+    get_node_details,
+    add_knowledge_node,
+    delete_knowledge_node,
+    rename_knowledge_node,
+    move_knowledge_node,
+    get_knowledge_graph_tree,
+    add_tags_to_knowledge_node,
+    remove_tags_from_knowledge_node,
+)
 from .request_input import request_admin_input
 from .screenshot import save_screenshot_to_file
 from .worker import worker, worker_gen, chatgroup
 from .click import find_and_click_element, scroll_screen
-from .subtasks import create_task, resume_task, get_all_tasks_status, get_task_result
+from .subtasks import create_task, resume_task, get_all_tasks_status, get_task_result, create_tasks_from_csv
 
 #显式导入 aient.plugins 中的所需内容
 from ..aient.src.aient.plugins import (
@@ -47,12 +58,22 @@ __all__ = [
     "list_directory",
     "get_task_result",
     "get_url_content",
+    "get_node_details",
+    "add_knowledge_node",
+    "move_knowledge_node",
+    "delete_knowledge_node",
+    "rename_knowledge_node",
+    "get_knowledge_graph_tree",
+    "add_tags_to_knowledge_node",
+    "remove_tags_from_knowledge_node",
+    "append_row_to_csv",
     "set_readonly_path",
     "get_code_repo_map",
     "run_python_script",
     "get_search_results",
     "request_admin_input",
     "get_all_tasks_status",
+    "create_tasks_from_csv",
     "find_and_click_element",
     "download_read_arxiv_pdf",
     "save_screenshot_to_file",
