@@ -9,7 +9,7 @@ def task_complete(message: str) -> str:
     它标志着一个任务的成功结束，并将最终的输出传递给用户或调用者。
 
     Args:
-        message (str): 任务完成的信息或最终结果。
+        message (str): 任务完成的信息或最终结果。必填字段。
 
     Returns:
         str: 传入的任务完成信息。
